MockHostBindings

Struct MockHostBindings 

pub struct MockHostBindings { /* private fields */ }
Trait defining all host functions available to WASM smart contracts.

This trait serves as the source of truth for host function signatures and is implemented by:

  • WasmHostBindings: The production implementation that calls actual host functions via FFI
  • EmptyHostBindings: Stub implementations for non-WASM builds (panics if called)
  • MockHostBindings: Generated by mockall for unit testing (via #[automock])

Example

use xrpl_common_stdlib::host::{HostBindings, WasmHostBindings};

fn my_function<H: HostBindings>(host: &H) {
    unsafe {
        let mut buffer = [0u8; 8];
        let result = host.ldgr_index(buffer.as_mut_ptr(), buffer.len());
        // ... use result
    }
}

// In production code:
let host = WasmHostBindings;
my_function(&host);

Implementations

Source

impl MockHostBindings

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockHostBindings

pub fn expect_ldgr_index(&mut self) -> &mut Expectation

Create an Expectation for mocking the ldgr_index method

pub fn expect_parent_ldgr_time(&mut self) -> &mut Expectation

Create an Expectation for mocking the parent_ldgr_time method

pub fn expect_parent_ldgr_hash(&mut self) -> &mut Expectation

Create an Expectation for mocking the parent_ldgr_hash method

pub fn expect_base_fee(&mut self) -> &mut Expectation

Create an Expectation for mocking the base_fee method

pub fn expect_amendment_enabled(&mut self) -> &mut Expectation

Create an Expectation for mocking the amendment_enabled method

pub fn expect_cache_le(&mut self) -> &mut Expectation

Create an Expectation for mocking the cache_le method

pub fn expect_tx_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the tx_field method

pub fn expect_home_le_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the home_le_field method

pub fn expect_le_field(&mut self) -> &mut Expectation

Create an Expectation for mocking the le_field method

pub fn expect_tx_inner(&mut self) -> &mut Expectation

Create an Expectation for mocking the tx_inner method

pub fn expect_home_le_inner(&mut self) -> &mut Expectation

Create an Expectation for mocking the home_le_inner method

pub fn expect_le_inner(&mut self) -> &mut Expectation

Create an Expectation for mocking the le_inner method

pub fn expect_tx_arr_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the tx_arr_len method

pub fn expect_home_le_arr_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the home_le_arr_len method

pub fn expect_le_arr_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the le_arr_len method

pub fn expect_tx_inner_arr_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the tx_inner_arr_len method

pub fn expect_home_le_inner_arr_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the home_le_inner_arr_len method

pub fn expect_le_inner_arr_len(&mut self) -> &mut Expectation

Create an Expectation for mocking the le_inner_arr_len method

pub fn expect_set_data(&mut self) -> &mut Expectation

Create an Expectation for mocking the set_data method

pub fn expect_sha512_half(&mut self) -> &mut Expectation

Create an Expectation for mocking the sha512_half method

pub fn expect_check_sig(&mut self) -> &mut Expectation

Create an Expectation for mocking the check_sig method

pub fn expect_accountroot_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the accountroot_id method

pub fn expect_amm_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the amm_id method

pub fn expect_check_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the check_id method

pub fn expect_credential_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the credential_id method

pub fn expect_delegate_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the delegate_id method

pub fn expect_deposit_preauth_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the deposit_preauth_id method

pub fn expect_did_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the did_id method

pub fn expect_escrow_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the escrow_id method

pub fn expect_trustline_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the trustline_id method

pub fn expect_mpt_issuance_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the mpt_issuance_id method

pub fn expect_mptoken_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the mptoken_id method

pub fn expect_nft_offer_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the nft_offer_id method

pub fn expect_offer_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the offer_id method

pub fn expect_oracle_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the oracle_id method

pub fn expect_paychan_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the paychan_id method

pub fn expect_permissioned_domain_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the permissioned_domain_id method

pub fn expect_signers_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the signers_id method

pub fn expect_ticket_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the ticket_id method

pub fn expect_vault_id(&mut self) -> &mut Expectation

Create an Expectation for mocking the vault_id method

pub fn expect_nft_uri(&mut self) -> &mut Expectation

Create an Expectation for mocking the nft_uri method

pub fn expect_nft_issuer(&mut self) -> &mut Expectation

Create an Expectation for mocking the nft_issuer method

pub fn expect_nft_taxon(&mut self) -> &mut Expectation

Create an Expectation for mocking the nft_taxon method

pub fn expect_nft_flags(&mut self) -> &mut Expectation

Create an Expectation for mocking the nft_flags method

pub fn expect_nft_xfer_fee(&mut self) -> &mut Expectation

Create an Expectation for mocking the nft_xfer_fee method

pub fn expect_nft_serial(&mut self) -> &mut Expectation

Create an Expectation for mocking the nft_serial method

pub fn expect_float_from_int(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_int method

pub fn expect_float_from_uint(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_uint method

pub fn expect_float_from_mant_exp(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_mant_exp method

pub fn expect_float_from_stamount(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_stamount method

pub fn expect_float_from_stnumber(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_from_stnumber method

pub fn expect_float_to_int(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_to_int method

pub fn expect_float_to_mant_exp(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_to_mant_exp method

pub fn expect_float_cmp(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_cmp method

pub fn expect_float_add(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_add method

pub fn expect_float_sub(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_sub method

pub fn expect_float_mult(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_mult method

pub fn expect_float_div(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_div method

pub fn expect_float_pow(&mut self) -> &mut Expectation

Create an Expectation for mocking the float_pow method

pub fn expect_trace(&mut self) -> &mut Expectation

Create an Expectation for mocking the trace method